/********************************************************************************
** Form generated from reading UI file 'qrpnframe.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QRPNFRAME_H
#define UI_QRPNFRAME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_qrpnframe
{
public:
    QGroupBox *group_box_rpn;
    QWidget *layoutWidgetSelectControl;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *radio_button_rpn;
    QRadioButton *radio_button_nrpn;
    QRadioButton *radio_button_rpn_data_slider;
    QRadioButton *radio_button_rpn_data_incr;
    QRadioButton *radio_button_rpn_data_decr;
    QGroupBox *group_box_rpn_value;
    QWidget *layoutWidgetSelectRPN;
    QVBoxLayout *verticalLayout;
    QRadioButton *radio_rpn_pitch_range;
    QRadioButton *radio_rpn_chan_fine_tuning;
    QRadioButton *radio_rpn_chan_coarse_tuning;
    QRadioButton *radio_rpn_tune_program_change;
    QRadioButton *radio_rpn_tune_bank_select;
    QRadioButton *radio_rpn_mod_depth_range;
    QRadioButton *radio_rpn_parameter_reset;
    QComboBox *combo_box_channel;
    QLabel *label;
    QLineEdit *line_edit_rpn_macro_name;
    QWidget *layoutWidgetAppendRPNrest;
    QHBoxLayout *horizontalLayout;
    QLabel *label_5;
    QLabel *label_pattern_no;
    QLabel *label_7;
    QPushButton *button_bbt;
    QWidget *lineEditLayoutWidget;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QLineEdit *line_edit_rpn_timestamp;
    QLabel *label_nrpn_param_number;
    QLineEdit *line_edit_nrpn_param_number;
    QLabel *label_3;
    QLineEdit *line_edit_rpn_param_value;
    QWidget *layoutWidget;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *button_rpn_macro;
    QPushButton *button_rpn_insert;
    QPushButton *button_rpn_cancel;
    QWidget *layoutWidget1;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *check_box_rpn_append_data;
    QCheckBox *check_box_rpn_append_reset;
    QCheckBox *check_box_rpn_use_fine;
    QLabel *label_warning;
    QPushButton *button_hex;
    QPushButton *button_reserved_1;
    QPushButton *button_reserved_2;

    void setupUi(QFrame *qrpnframe)
    {
        if (qrpnframe->objectName().isEmpty())
            qrpnframe->setObjectName(QString::fromUtf8("qrpnframe"));
        qrpnframe->resize(794, 405);
        group_box_rpn = new QGroupBox(qrpnframe);
        group_box_rpn->setObjectName(QString::fromUtf8("group_box_rpn"));
        group_box_rpn->setGeometry(QRect(20, 40, 241, 211));
        QFont font;
        font.setBold(true);
        group_box_rpn->setFont(font);
        layoutWidgetSelectControl = new QWidget(group_box_rpn);
        layoutWidgetSelectControl->setObjectName(QString::fromUtf8("layoutWidgetSelectControl"));
        layoutWidgetSelectControl->setGeometry(QRect(10, 40, 221, 161));
        verticalLayout_2 = new QVBoxLayout(layoutWidgetSelectControl);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        radio_button_rpn = new QRadioButton(layoutWidgetSelectControl);
        radio_button_rpn->setObjectName(QString::fromUtf8("radio_button_rpn"));
        QFont font1;
        font1.setBold(false);
        radio_button_rpn->setFont(font1);

        verticalLayout_2->addWidget(radio_button_rpn);

        radio_button_nrpn = new QRadioButton(layoutWidgetSelectControl);
        radio_button_nrpn->setObjectName(QString::fromUtf8("radio_button_nrpn"));
        radio_button_nrpn->setFont(font1);

        verticalLayout_2->addWidget(radio_button_nrpn);

        radio_button_rpn_data_slider = new QRadioButton(layoutWidgetSelectControl);
        radio_button_rpn_data_slider->setObjectName(QString::fromUtf8("radio_button_rpn_data_slider"));
        QFont font2;
        font2.setBold(false);
        font2.setItalic(true);
        radio_button_rpn_data_slider->setFont(font2);

        verticalLayout_2->addWidget(radio_button_rpn_data_slider);

        radio_button_rpn_data_incr = new QRadioButton(layoutWidgetSelectControl);
        radio_button_rpn_data_incr->setObjectName(QString::fromUtf8("radio_button_rpn_data_incr"));
        radio_button_rpn_data_incr->setEnabled(false);
        radio_button_rpn_data_incr->setFont(font1);

        verticalLayout_2->addWidget(radio_button_rpn_data_incr);

        radio_button_rpn_data_decr = new QRadioButton(layoutWidgetSelectControl);
        radio_button_rpn_data_decr->setObjectName(QString::fromUtf8("radio_button_rpn_data_decr"));
        radio_button_rpn_data_decr->setEnabled(false);
        radio_button_rpn_data_decr->setFont(font1);

        verticalLayout_2->addWidget(radio_button_rpn_data_decr);

        group_box_rpn_value = new QGroupBox(qrpnframe);
        group_box_rpn_value->setObjectName(QString::fromUtf8("group_box_rpn_value"));
        group_box_rpn_value->setGeometry(QRect(510, 40, 261, 261));
        group_box_rpn_value->setFont(font);
        layoutWidgetSelectRPN = new QWidget(group_box_rpn_value);
        layoutWidgetSelectRPN->setObjectName(QString::fromUtf8("layoutWidgetSelectRPN"));
        layoutWidgetSelectRPN->setGeometry(QRect(10, 30, 241, 227));
        verticalLayout = new QVBoxLayout(layoutWidgetSelectRPN);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        radio_rpn_pitch_range = new QRadioButton(layoutWidgetSelectRPN);
        radio_rpn_pitch_range->setObjectName(QString::fromUtf8("radio_rpn_pitch_range"));
        radio_rpn_pitch_range->setFont(font1);

        verticalLayout->addWidget(radio_rpn_pitch_range);

        radio_rpn_chan_fine_tuning = new QRadioButton(layoutWidgetSelectRPN);
        radio_rpn_chan_fine_tuning->setObjectName(QString::fromUtf8("radio_rpn_chan_fine_tuning"));
        radio_rpn_chan_fine_tuning->setFont(font1);

        verticalLayout->addWidget(radio_rpn_chan_fine_tuning);

        radio_rpn_chan_coarse_tuning = new QRadioButton(layoutWidgetSelectRPN);
        radio_rpn_chan_coarse_tuning->setObjectName(QString::fromUtf8("radio_rpn_chan_coarse_tuning"));
        radio_rpn_chan_coarse_tuning->setFont(font1);

        verticalLayout->addWidget(radio_rpn_chan_coarse_tuning);

        radio_rpn_tune_program_change = new QRadioButton(layoutWidgetSelectRPN);
        radio_rpn_tune_program_change->setObjectName(QString::fromUtf8("radio_rpn_tune_program_change"));
        radio_rpn_tune_program_change->setFont(font1);

        verticalLayout->addWidget(radio_rpn_tune_program_change);

        radio_rpn_tune_bank_select = new QRadioButton(layoutWidgetSelectRPN);
        radio_rpn_tune_bank_select->setObjectName(QString::fromUtf8("radio_rpn_tune_bank_select"));
        radio_rpn_tune_bank_select->setFont(font1);

        verticalLayout->addWidget(radio_rpn_tune_bank_select);

        radio_rpn_mod_depth_range = new QRadioButton(layoutWidgetSelectRPN);
        radio_rpn_mod_depth_range->setObjectName(QString::fromUtf8("radio_rpn_mod_depth_range"));
        radio_rpn_mod_depth_range->setFont(font1);

        verticalLayout->addWidget(radio_rpn_mod_depth_range);

        radio_rpn_parameter_reset = new QRadioButton(layoutWidgetSelectRPN);
        radio_rpn_parameter_reset->setObjectName(QString::fromUtf8("radio_rpn_parameter_reset"));
        radio_rpn_parameter_reset->setFont(font2);

        verticalLayout->addWidget(radio_rpn_parameter_reset);

        combo_box_channel = new QComboBox(qrpnframe);
        combo_box_channel->setObjectName(QString::fromUtf8("combo_box_channel"));
        combo_box_channel->setGeometry(QRect(360, 40, 86, 30));
        label = new QLabel(qrpnframe);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(270, 40, 71, 22));
        label->setFont(font);
        line_edit_rpn_macro_name = new QLineEdit(qrpnframe);
        line_edit_rpn_macro_name->setObjectName(QString::fromUtf8("line_edit_rpn_macro_name"));
        line_edit_rpn_macro_name->setGeometry(QRect(371, 306, 126, 30));
        QFont font3;
        font3.setItalic(true);
        line_edit_rpn_macro_name->setFont(font3);
        line_edit_rpn_macro_name->setFrame(true);
        layoutWidgetAppendRPNrest = new QWidget(qrpnframe);
        layoutWidgetAppendRPNrest->setObjectName(QString::fromUtf8("layoutWidgetAppendRPNrest"));
        layoutWidgetAppendRPNrest->setGeometry(QRect(30, 10, 251, 24));
        horizontalLayout = new QHBoxLayout(layoutWidgetAppendRPNrest);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        label_5 = new QLabel(layoutWidgetAppendRPNrest);
        label_5->setObjectName(QString::fromUtf8("label_5"));
        label_5->setFont(font);

        horizontalLayout->addWidget(label_5);

        label_pattern_no = new QLabel(layoutWidgetAppendRPNrest);
        label_pattern_no->setObjectName(QString::fromUtf8("label_pattern_no"));
        label_pattern_no->setFont(font3);
        label_pattern_no->setIndent(1);

        horizontalLayout->addWidget(label_pattern_no);

        label_7 = new QLabel(qrpnframe);
        label_7->setObjectName(QString::fromUtf8("label_7"));
        label_7->setGeometry(QRect(280, 190, 211, 61));
        QFont font4;
        font4.setPointSize(8);
        font4.setItalic(true);
        label_7->setFont(font4);
        button_bbt = new QPushButton(qrpnframe);
        button_bbt->setObjectName(QString::fromUtf8("button_bbt"));
        button_bbt->setGeometry(QRect(370, 265, 60, 30));
        lineEditLayoutWidget = new QWidget(qrpnframe);
        lineEditLayoutWidget->setObjectName(QString::fromUtf8("lineEditLayoutWidget"));
        lineEditLayoutWidget->setGeometry(QRect(21, 260, 341, 121));
        gridLayout = new QGridLayout(lineEditLayoutWidget);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(lineEditLayoutWidget);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        line_edit_rpn_timestamp = new QLineEdit(lineEditLayoutWidget);
        line_edit_rpn_timestamp->setObjectName(QString::fromUtf8("line_edit_rpn_timestamp"));

        gridLayout->addWidget(line_edit_rpn_timestamp, 0, 1, 1, 1);

        label_nrpn_param_number = new QLabel(lineEditLayoutWidget);
        label_nrpn_param_number->setObjectName(QString::fromUtf8("label_nrpn_param_number"));

        gridLayout->addWidget(label_nrpn_param_number, 1, 0, 1, 1);

        line_edit_nrpn_param_number = new QLineEdit(lineEditLayoutWidget);
        line_edit_nrpn_param_number->setObjectName(QString::fromUtf8("line_edit_nrpn_param_number"));

        gridLayout->addWidget(line_edit_nrpn_param_number, 1, 1, 1, 1);

        label_3 = new QLabel(lineEditLayoutWidget);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        line_edit_rpn_param_value = new QLineEdit(lineEditLayoutWidget);
        line_edit_rpn_param_value->setObjectName(QString::fromUtf8("line_edit_rpn_param_value"));

        gridLayout->addWidget(line_edit_rpn_param_value, 2, 1, 1, 1);

        layoutWidget = new QWidget(qrpnframe);
        layoutWidget->setObjectName(QString::fromUtf8("layoutWidget"));
        layoutWidget->setGeometry(QRect(370, 342, 391, 36));
        horizontalLayout_2 = new QHBoxLayout(layoutWidget);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        button_rpn_macro = new QPushButton(layoutWidget);
        button_rpn_macro->setObjectName(QString::fromUtf8("button_rpn_macro"));

        horizontalLayout_2->addWidget(button_rpn_macro);

        button_rpn_insert = new QPushButton(layoutWidget);
        button_rpn_insert->setObjectName(QString::fromUtf8("button_rpn_insert"));

        horizontalLayout_2->addWidget(button_rpn_insert);

        button_rpn_cancel = new QPushButton(layoutWidget);
        button_rpn_cancel->setObjectName(QString::fromUtf8("button_rpn_cancel"));

        horizontalLayout_2->addWidget(button_rpn_cancel);

        layoutWidget1 = new QWidget(qrpnframe);
        layoutWidget1->setObjectName(QString::fromUtf8("layoutWidget1"));
        layoutWidget1->setGeometry(QRect(280, 81, 212, 95));
        verticalLayout_3 = new QVBoxLayout(layoutWidget1);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        check_box_rpn_append_data = new QCheckBox(layoutWidget1);
        check_box_rpn_append_data->setObjectName(QString::fromUtf8("check_box_rpn_append_data"));

        verticalLayout_3->addWidget(check_box_rpn_append_data);

        check_box_rpn_append_reset = new QCheckBox(layoutWidget1);
        check_box_rpn_append_reset->setObjectName(QString::fromUtf8("check_box_rpn_append_reset"));

        verticalLayout_3->addWidget(check_box_rpn_append_reset);

        check_box_rpn_use_fine = new QCheckBox(layoutWidget1);
        check_box_rpn_use_fine->setObjectName(QString::fromUtf8("check_box_rpn_use_fine"));

        verticalLayout_3->addWidget(check_box_rpn_use_fine);

        label_warning = new QLabel(qrpnframe);
        label_warning->setObjectName(QString::fromUtf8("label_warning"));
        label_warning->setEnabled(false);
        label_warning->setGeometry(QRect(290, 11, 491, 21));
        QFont font5;
        font5.setPointSize(9);
        font5.setBold(true);
        font5.setItalic(true);
        label_warning->setFont(font5);
        label_warning->setFrameShape(QFrame::Shape::NoFrame);
        label_warning->setFrameShadow(QFrame::Shadow::Sunken);
        label_warning->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByMouse|Qt::TextInteractionFlag::TextEditable);
        button_hex = new QPushButton(qrpnframe);
        button_hex->setObjectName(QString::fromUtf8("button_hex"));
        button_hex->setGeometry(QRect(436, 265, 60, 30));
        button_hex->setCheckable(true);
        button_reserved_1 = new QPushButton(qrpnframe);
        button_reserved_1->setObjectName(QString::fromUtf8("button_reserved_1"));
        button_reserved_1->setEnabled(false);
        button_reserved_1->setGeometry(QRect(504, 307, 125, 30));
        button_reserved_2 = new QPushButton(qrpnframe);
        button_reserved_2->setObjectName(QString::fromUtf8("button_reserved_2"));
        button_reserved_2->setEnabled(false);
        button_reserved_2->setGeometry(QRect(634, 307, 126, 30));

        retranslateUi(qrpnframe);

        QMetaObject::connectSlotsByName(qrpnframe);
    } // setupUi

    void retranslateUi(QFrame *qrpnframe)
    {
        qrpnframe->setWindowTitle(QCoreApplication::translate("qrpnframe", "RPN Editor", nullptr));
        group_box_rpn->setTitle(QCoreApplication::translate("qrpnframe", "Select Control", nullptr));
        radio_button_rpn->setText(QCoreApplication::translate("qrpnframe", "&RPN", nullptr));
        radio_button_nrpn->setText(QCoreApplication::translate("qrpnframe", "&NRPN", nullptr));
        radio_button_rpn_data_slider->setText(QCoreApplication::translate("qrpnframe", "&Data entry slider", nullptr));
        radio_button_rpn_data_incr->setText(QCoreApplication::translate("qrpnframe", "Data button increment", nullptr));
        radio_button_rpn_data_decr->setText(QCoreApplication::translate("qrpnframe", "Data button decrement", nullptr));
        group_box_rpn_value->setTitle(QCoreApplication::translate("qrpnframe", "Select RPN", nullptr));
        radio_rpn_pitch_range->setText(QCoreApplication::translate("qrpnframe", "&Pitchbend range", nullptr));
        radio_rpn_chan_fine_tuning->setText(QCoreApplication::translate("qrpnframe", "Channel &fine tuning", nullptr));
        radio_rpn_chan_coarse_tuning->setText(QCoreApplication::translate("qrpnframe", "Channel &coarse tuning", nullptr));
        radio_rpn_tune_program_change->setText(QCoreApplication::translate("qrpnframe", "Tuning program change", nullptr));
        radio_rpn_tune_bank_select->setText(QCoreApplication::translate("qrpnframe", "Tuning bank select", nullptr));
        radio_rpn_mod_depth_range->setText(QCoreApplication::translate("qrpnframe", "&Modulation depth range", nullptr));
        radio_rpn_parameter_reset->setText(QCoreApplication::translate("qrpnframe", "RPN parameter reset", nullptr));
#if QT_CONFIG(tooltip)
        combo_box_channel->setToolTip(QCoreApplication::translate("qrpnframe", "Selects the channel number to use with the controller.", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(QCoreApplication::translate("qrpnframe", "Channel", nullptr));
#if QT_CONFIG(tooltip)
        line_edit_rpn_macro_name->setToolTip(QCoreApplication::translate("qrpnframe", "The name of the macro to add\n"
"to the 'ctrl' file.", nullptr));
#endif // QT_CONFIG(tooltip)
        line_edit_rpn_macro_name->setText(QString());
        label_5->setText(QCoreApplication::translate("qrpnframe", "RPN/NRPN Editor", nullptr));
        label_pattern_no->setText(QCoreApplication::translate("qrpnframe", "Pattern #xxxx", nullptr));
        label_7->setText(QCoreApplication::translate("qrpnframe", "RPN and NRPN use the data entry\n"
"slider by default. RPN reset is\n"
"added by default (recommended).", nullptr));
#if QT_CONFIG(tooltip)
        button_bbt->setToolTip(QCoreApplication::translate("qrpnframe", "Changes the time format between BBT, HMS,\n"
"and ticks.", nullptr));
#endif // QT_CONFIG(tooltip)
        button_bbt->setText(QCoreApplication::translate("qrpnframe", "BBT", nullptr));
        label_2->setText(QCoreApplication::translate("qrpnframe", "Timestamp (BBT)", nullptr));
#if QT_CONFIG(tooltip)
        line_edit_rpn_timestamp->setToolTip(QCoreApplication::translate("qrpnframe", "Provide or show the timestamp.", nullptr));
#endif // QT_CONFIG(tooltip)
        line_edit_rpn_timestamp->setText(QCoreApplication::translate("qrpnframe", "100:02:1234", nullptr));
        label_nrpn_param_number->setText(QCoreApplication::translate("qrpnframe", "(N)RPN parameter no.", nullptr));
        line_edit_nrpn_param_number->setText(QCoreApplication::translate("qrpnframe", "0x00", nullptr));
        label_3->setText(QCoreApplication::translate("qrpnframe", "RPN/NRPN parameter value", nullptr));
#if QT_CONFIG(tooltip)
        line_edit_rpn_param_value->setToolTip(QCoreApplication::translate("qrpnframe", "Supply the parameter value as an integer\n"
"or, to also set the \"fine\" values or the \"cents\"\n"
"value, type a real number, e.g. 12.90 to\n"
"specify a pitch change of 12 semitones and\n"
"90 cents.", nullptr));
#endif // QT_CONFIG(tooltip)
        line_edit_rpn_param_value->setText(QCoreApplication::translate("qrpnframe", "0.0", nullptr));
#if QT_CONFIG(tooltip)
        button_rpn_macro->setToolTip(QCoreApplication::translate("qrpnframe", "Copy the event data to a MIDI-control-out\n"
"macro.", nullptr));
#endif // QT_CONFIG(tooltip)
        button_rpn_macro->setText(QCoreApplication::translate("qrpnframe", "Create Macro", nullptr));
#if QT_CONFIG(tooltip)
        button_rpn_insert->setToolTip(QCoreApplication::translate("qrpnframe", "Inserts the controller events at the given timestamp.", nullptr));
#endif // QT_CONFIG(tooltip)
        button_rpn_insert->setText(QCoreApplication::translate("qrpnframe", "&Insert (N)RPN", nullptr));
#if QT_CONFIG(tooltip)
        button_rpn_cancel->setToolTip(QCoreApplication::translate("qrpnframe", "Close the dialog.", nullptr));
#endif // QT_CONFIG(tooltip)
        button_rpn_cancel->setText(QCoreApplication::translate("qrpnframe", "Close", nullptr));
#if QT_CONFIG(tooltip)
        check_box_rpn_append_data->setToolTip(QCoreApplication::translate("qrpnframe", "Use a parameter value.", nullptr));
#endif // QT_CONFIG(tooltip)
        check_box_rpn_append_data->setText(QCoreApplication::translate("qrpnframe", "Append data entry slider", nullptr));
#if QT_CONFIG(tooltip)
        check_box_rpn_append_reset->setToolTip(QCoreApplication::translate("qrpnframe", "Close out the setting change. Recommended.", nullptr));
#endif // QT_CONFIG(tooltip)
        check_box_rpn_append_reset->setText(QCoreApplication::translate("qrpnframe", "Append RPN reset", nullptr));
#if QT_CONFIG(tooltip)
        check_box_rpn_use_fine->setToolTip(QCoreApplication::translate("qrpnframe", "Apply the \"fine\" version of each control\n"
"as well as the \"coarse\" version.", nullptr));
#endif // QT_CONFIG(tooltip)
        check_box_rpn_use_fine->setText(QCoreApplication::translate("qrpnframe", "Use \"fine\" events", nullptr));
        label_warning->setText(QString());
        button_hex->setText(QCoreApplication::translate("qrpnframe", "Hex", nullptr));
        button_reserved_1->setText(QCoreApplication::translate("qrpnframe", "Reserved", nullptr));
        button_reserved_2->setText(QCoreApplication::translate("qrpnframe", "Reserved", nullptr));
    } // retranslateUi

};

namespace Ui {
    class qrpnframe: public Ui_qrpnframe {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QRPNFRAME_H
