/****************************************************************************
** Meta object code from reading C++ file 'qrpnframe.hpp'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../seq66-0.99.27/seq_qt5/src/gui/qrpnframe.hpp"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qrpnframe.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_seq66__qrpnframe_t {
    QByteArrayData data[21];
    char stringdata0[370];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_seq66__qrpnframe_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_seq66__qrpnframe_t qt_meta_stringdata_seq66__qrpnframe = {
    {
QT_MOC_LITERAL(0, 0, 16), // "seq66::qrpnframe"
QT_MOC_LITERAL(1, 17, 23), // "slot_select_rpn_control"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 1), // "r"
QT_MOC_LITERAL(4, 44, 17), // "slot_midi_channel"
QT_MOC_LITERAL(5, 62, 1), // "c"
QT_MOC_LITERAL(6, 64, 20), // "slot_rpn_append_data"
QT_MOC_LITERAL(7, 85, 5), // "state"
QT_MOC_LITERAL(8, 91, 21), // "slot_rpn_append_reset"
QT_MOC_LITERAL(9, 113, 21), // "slot_rpn_use_fine_rpn"
QT_MOC_LITERAL(10, 135, 30), // "slot_select_rpn_parameter_type"
QT_MOC_LITERAL(11, 166, 1), // "v"
QT_MOC_LITERAL(12, 168, 21), // "slot_next_time_format"
QT_MOC_LITERAL(13, 190, 27), // "slot_timestamp_text_changed"
QT_MOC_LITERAL(14, 218, 30), // "slot_param_number_text_changed"
QT_MOC_LITERAL(15, 249, 29), // "slot_param_value_text_changed"
QT_MOC_LITERAL(16, 279, 16), // "slot_show_in_hex"
QT_MOC_LITERAL(17, 296, 23), // "slot_macro_name_changed"
QT_MOC_LITERAL(18, 320, 17), // "slot_create_macro"
QT_MOC_LITERAL(19, 338, 15), // "slot_rpn_insert"
QT_MOC_LITERAL(20, 354, 15) // "slot_rpn_cancel"

    },
    "seq66::qrpnframe\0slot_select_rpn_control\0"
    "\0r\0slot_midi_channel\0c\0slot_rpn_append_data\0"
    "state\0slot_rpn_append_reset\0"
    "slot_rpn_use_fine_rpn\0"
    "slot_select_rpn_parameter_type\0v\0"
    "slot_next_time_format\0slot_timestamp_text_changed\0"
    "slot_param_number_text_changed\0"
    "slot_param_value_text_changed\0"
    "slot_show_in_hex\0slot_macro_name_changed\0"
    "slot_create_macro\0slot_rpn_insert\0"
    "slot_rpn_cancel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_seq66__qrpnframe[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   89,    2, 0x08 /* Private */,
       4,    1,   92,    2, 0x08 /* Private */,
       6,    1,   95,    2, 0x08 /* Private */,
       8,    1,   98,    2, 0x08 /* Private */,
       9,    1,  101,    2, 0x08 /* Private */,
      10,    1,  104,    2, 0x08 /* Private */,
      12,    0,  107,    2, 0x08 /* Private */,
      13,    0,  108,    2, 0x08 /* Private */,
      14,    0,  109,    2, 0x08 /* Private */,
      15,    0,  110,    2, 0x08 /* Private */,
      16,    0,  111,    2, 0x08 /* Private */,
      17,    0,  112,    2, 0x08 /* Private */,
      18,    0,  113,    2, 0x08 /* Private */,
      19,    0,  114,    2, 0x08 /* Private */,
      20,    0,  115,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void seq66::qrpnframe::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<qrpnframe *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slot_select_rpn_control((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->slot_midi_channel((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->slot_rpn_append_data((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->slot_rpn_append_reset((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->slot_rpn_use_fine_rpn((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->slot_select_rpn_parameter_type((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->slot_next_time_format(); break;
        case 7: _t->slot_timestamp_text_changed(); break;
        case 8: _t->slot_param_number_text_changed(); break;
        case 9: _t->slot_param_value_text_changed(); break;
        case 10: _t->slot_show_in_hex(); break;
        case 11: _t->slot_macro_name_changed(); break;
        case 12: _t->slot_create_macro(); break;
        case 13: _t->slot_rpn_insert(); break;
        case 14: _t->slot_rpn_cancel(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject seq66::qrpnframe::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_seq66__qrpnframe.data,
    qt_meta_data_seq66__qrpnframe,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *seq66::qrpnframe::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *seq66::qrpnframe::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_seq66__qrpnframe.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int seq66::qrpnframe::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
