/********************************************************************************
** Form generated from reading UI file 'qlearnframe.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QLEARNFRAME_H
#define UI_QLEARNFRAME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_qlearnframe
{
public:
    QWidget *layoutWidget;
    QGridLayout *learn_grid_layout;
    QRadioButton *automation_button;
    QLineEdit *loops_line_edit;
    QRadioButton *loops_button;
    QRadioButton *mutes_button;
    QRadioButton *radio_action_on;
    QLabel *label;
    QLineEdit *automation_line_edit;
    QRadioButton *radio_action_toggle;
    QLabel *learn_label;
    QLineEdit *mutes_line_edit;
    QLabel *active_events_label;
    QRadioButton *radio_action_off;
    QRadioButton *radio_action_hold;
    QWidget *layoutWidgetNextControl;
    QHBoxLayout *horizontalLayout;
    QLabel *current_logged_control_label;
    QLineEdit *current_logged_control_line_edit;
    QWidget *layoutWidgetGrid;
    QGridLayout *gridLayout_2;
    QPushButton *reserved_push_button;
    QCheckBox *inverse_check_box;
    QLabel *label_2;
    QLineEdit *d1min_line_edit;
    QLabel *label_3;
    QLineEdit *d1max_line_edit;
    QPushButton *ok_push_button;
    QPushButton *cancel_push_button;
    QWidget *layoutWidgetButtons;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *save_push_button;
    QPushButton *reset_push_button;
    QPushButton *clear_push_button;
    QPushButton *clear_all_push_button;

    void setupUi(QFrame *qlearnframe)
    {
        if (qlearnframe->objectName().isEmpty())
            qlearnframe->setObjectName(QString::fromUtf8("qlearnframe"));
        qlearnframe->resize(628, 223);
        qlearnframe->setFrameShape(QFrame::StyledPanel);
        layoutWidget = new QWidget(qlearnframe);
        layoutWidget->setObjectName(QString::fromUtf8("layoutWidget"));
        layoutWidget->setGeometry(QRect(10, 13, 321, 158));
        learn_grid_layout = new QGridLayout(layoutWidget);
        learn_grid_layout->setObjectName(QString::fromUtf8("learn_grid_layout"));
        learn_grid_layout->setHorizontalSpacing(12);
        learn_grid_layout->setContentsMargins(0, 0, 0, 0);
        automation_button = new QRadioButton(layoutWidget);
        automation_button->setObjectName(QString::fromUtf8("automation_button"));
        QFont font;
        font.setPointSize(10);
        automation_button->setFont(font);

        learn_grid_layout->addWidget(automation_button, 3, 0, 1, 1);

        loops_line_edit = new QLineEdit(layoutWidget);
        loops_line_edit->setObjectName(QString::fromUtf8("loops_line_edit"));

        learn_grid_layout->addWidget(loops_line_edit, 1, 1, 1, 1);

        loops_button = new QRadioButton(layoutWidget);
        loops_button->setObjectName(QString::fromUtf8("loops_button"));
        loops_button->setFont(font);

        learn_grid_layout->addWidget(loops_button, 1, 0, 1, 1);

        mutes_button = new QRadioButton(layoutWidget);
        mutes_button->setObjectName(QString::fromUtf8("mutes_button"));
        mutes_button->setFont(font);

        learn_grid_layout->addWidget(mutes_button, 2, 0, 1, 1);

        radio_action_on = new QRadioButton(layoutWidget);
        radio_action_on->setObjectName(QString::fromUtf8("radio_action_on"));

        learn_grid_layout->addWidget(radio_action_on, 2, 2, 1, 1);

        label = new QLabel(layoutWidget);
        label->setObjectName(QString::fromUtf8("label"));
        QFont font1;
        font1.setBold(true);
        label->setFont(font1);

        learn_grid_layout->addWidget(label, 0, 2, 1, 1);

        automation_line_edit = new QLineEdit(layoutWidget);
        automation_line_edit->setObjectName(QString::fromUtf8("automation_line_edit"));

        learn_grid_layout->addWidget(automation_line_edit, 3, 1, 1, 1);

        radio_action_toggle = new QRadioButton(layoutWidget);
        radio_action_toggle->setObjectName(QString::fromUtf8("radio_action_toggle"));

        learn_grid_layout->addWidget(radio_action_toggle, 1, 2, 1, 1);

        learn_label = new QLabel(layoutWidget);
        learn_label->setObjectName(QString::fromUtf8("learn_label"));
        QFont font2;
        font2.setPointSize(10);
        font2.setBold(true);
        learn_label->setFont(font2);

        learn_grid_layout->addWidget(learn_label, 0, 0, 1, 1);

        mutes_line_edit = new QLineEdit(layoutWidget);
        mutes_line_edit->setObjectName(QString::fromUtf8("mutes_line_edit"));

        learn_grid_layout->addWidget(mutes_line_edit, 2, 1, 1, 1);

        active_events_label = new QLabel(layoutWidget);
        active_events_label->setObjectName(QString::fromUtf8("active_events_label"));
        active_events_label->setFont(font2);

        learn_grid_layout->addWidget(active_events_label, 0, 1, 1, 1);

        radio_action_off = new QRadioButton(layoutWidget);
        radio_action_off->setObjectName(QString::fromUtf8("radio_action_off"));

        learn_grid_layout->addWidget(radio_action_off, 3, 2, 1, 1);

        radio_action_hold = new QRadioButton(layoutWidget);
        radio_action_hold->setObjectName(QString::fromUtf8("radio_action_hold"));

        learn_grid_layout->addWidget(radio_action_hold, 4, 2, 1, 1);

        learn_grid_layout->setColumnStretch(0, 2);
        learn_grid_layout->setColumnStretch(1, 1);
        learn_grid_layout->setColumnStretch(2, 3);
        layoutWidgetNextControl = new QWidget(qlearnframe);
        layoutWidgetNextControl->setObjectName(QString::fromUtf8("layoutWidgetNextControl"));
        layoutWidgetNextControl->setGeometry(QRect(340, 10, 271, 34));
        horizontalLayout = new QHBoxLayout(layoutWidgetNextControl);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        current_logged_control_label = new QLabel(layoutWidgetNextControl);
        current_logged_control_label->setObjectName(QString::fromUtf8("current_logged_control_label"));
        current_logged_control_label->setFont(font2);

        horizontalLayout->addWidget(current_logged_control_label);

        current_logged_control_line_edit = new QLineEdit(layoutWidgetNextControl);
        current_logged_control_line_edit->setObjectName(QString::fromUtf8("current_logged_control_line_edit"));

        horizontalLayout->addWidget(current_logged_control_line_edit);

        layoutWidgetGrid = new QWidget(qlearnframe);
        layoutWidgetGrid->setObjectName(QString::fromUtf8("layoutWidgetGrid"));
        layoutWidgetGrid->setGeometry(QRect(340, 45, 178, 104));
        gridLayout_2 = new QGridLayout(layoutWidgetGrid);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        reserved_push_button = new QPushButton(layoutWidgetGrid);
        reserved_push_button->setObjectName(QString::fromUtf8("reserved_push_button"));

        gridLayout_2->addWidget(reserved_push_button, 0, 0, 1, 1);

        inverse_check_box = new QCheckBox(layoutWidgetGrid);
        inverse_check_box->setObjectName(QString::fromUtf8("inverse_check_box"));

        gridLayout_2->addWidget(inverse_check_box, 0, 1, 1, 1);

        label_2 = new QLabel(layoutWidgetGrid);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout_2->addWidget(label_2, 1, 0, 1, 1);

        d1min_line_edit = new QLineEdit(layoutWidgetGrid);
        d1min_line_edit->setObjectName(QString::fromUtf8("d1min_line_edit"));

        gridLayout_2->addWidget(d1min_line_edit, 1, 1, 1, 1);

        label_3 = new QLabel(layoutWidgetGrid);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout_2->addWidget(label_3, 2, 0, 1, 1);

        d1max_line_edit = new QLineEdit(layoutWidgetGrid);
        d1max_line_edit->setObjectName(QString::fromUtf8("d1max_line_edit"));

        gridLayout_2->addWidget(d1max_line_edit, 2, 1, 1, 1);

        ok_push_button = new QPushButton(qlearnframe);
        ok_push_button->setObjectName(QString::fromUtf8("ok_push_button"));
        ok_push_button->setGeometry(QRect(530, 77, 80, 26));
        ok_push_button->setFont(font);
        cancel_push_button = new QPushButton(qlearnframe);
        cancel_push_button->setObjectName(QString::fromUtf8("cancel_push_button"));
        cancel_push_button->setGeometry(QRect(530, 110, 80, 26));
        cancel_push_button->setFont(font);
        layoutWidgetButtons = new QWidget(qlearnframe);
        layoutWidgetButtons->setObjectName(QString::fromUtf8("layoutWidgetButtons"));
        layoutWidgetButtons->setGeometry(QRect(21, 180, 581, 34));
        horizontalLayout_2 = new QHBoxLayout(layoutWidgetButtons);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        save_push_button = new QPushButton(layoutWidgetButtons);
        save_push_button->setObjectName(QString::fromUtf8("save_push_button"));
        save_push_button->setFont(font);

        horizontalLayout_2->addWidget(save_push_button);

        reset_push_button = new QPushButton(layoutWidgetButtons);
        reset_push_button->setObjectName(QString::fromUtf8("reset_push_button"));
        reset_push_button->setFont(font);

        horizontalLayout_2->addWidget(reset_push_button);

        clear_push_button = new QPushButton(layoutWidgetButtons);
        clear_push_button->setObjectName(QString::fromUtf8("clear_push_button"));

        horizontalLayout_2->addWidget(clear_push_button);

        clear_all_push_button = new QPushButton(layoutWidgetButtons);
        clear_all_push_button->setObjectName(QString::fromUtf8("clear_all_push_button"));
        QFont font3;
        font3.setPointSize(10);
        font3.setBold(false);
        clear_all_push_button->setFont(font3);

        horizontalLayout_2->addWidget(clear_all_push_button);


        retranslateUi(qlearnframe);

        QMetaObject::connectSlotsByName(qlearnframe);
    } // setupUi

    void retranslateUi(QFrame *qlearnframe)
    {
        qlearnframe->setWindowTitle(QCoreApplication::translate("qlearnframe", "MIDI Learn Manager", nullptr));
#if QT_CONFIG(tooltip)
        automation_button->setToolTip(QCoreApplication::translate("qlearnframe", "If checked, map the incoming MIDI event\n"
"to the last GUI or keystroke element clicked.", nullptr));
#endif // QT_CONFIG(tooltip)
        automation_button->setText(QCoreApplication::translate("qlearnframe", "&Automation", nullptr));
#if QT_CONFIG(tooltip)
        loops_button->setToolTip(QCoreApplication::translate("qlearnframe", "If checked, auto-increment to the next pattern/loop\n"
"number when a control device button is clicked.", nullptr));
#endif // QT_CONFIG(tooltip)
        loops_button->setText(QCoreApplication::translate("qlearnframe", "&Loop", nullptr));
#if QT_CONFIG(tooltip)
        mutes_button->setToolTip(QCoreApplication::translate("qlearnframe", "If checked, auto-increment to the next mute-group\n"
"number when a control device button is clicked.", nullptr));
#endif // QT_CONFIG(tooltip)
        mutes_button->setText(QCoreApplication::translate("qlearnframe", "&Mute Groups", nullptr));
#if QT_CONFIG(tooltip)
        radio_action_on->setToolTip(QCoreApplication::translate("qlearnframe", "All recorded actions will be \"on\" actions.", nullptr));
#endif // QT_CONFIG(tooltip)
        radio_action_on->setText(QCoreApplication::translate("qlearnframe", "O&n", nullptr));
        label->setText(QCoreApplication::translate("qlearnframe", "Action", nullptr));
#if QT_CONFIG(tooltip)
        radio_action_toggle->setToolTip(QCoreApplication::translate("qlearnframe", "All recorded actions will be \"toggle\" actions.", nullptr));
#endif // QT_CONFIG(tooltip)
        radio_action_toggle->setText(QCoreApplication::translate("qlearnframe", "&Toggle", nullptr));
        learn_label->setText(QCoreApplication::translate("qlearnframe", "Learn", nullptr));
        active_events_label->setText(QCoreApplication::translate("qlearnframe", "Active Events", nullptr));
#if QT_CONFIG(tooltip)
        radio_action_off->setToolTip(QCoreApplication::translate("qlearnframe", "All recorded actions will be \"off\" actions.", nullptr));
#endif // QT_CONFIG(tooltip)
        radio_action_off->setText(QCoreApplication::translate("qlearnframe", "O&ff", nullptr));
#if QT_CONFIG(tooltip)
        radio_action_hold->setToolTip(QCoreApplication::translate("qlearnframe", "A control pressed will be logged as an \"on\" action,\n"
"while the release will be logged as an \"off\" action.", nullptr));
#endif // QT_CONFIG(tooltip)
        radio_action_hold->setText(QCoreApplication::translate("qlearnframe", "&Hold", nullptr));
        current_logged_control_label->setText(QCoreApplication::translate("qlearnframe", "Control", nullptr));
        reserved_push_button->setText(QString());
#if QT_CONFIG(tooltip)
        inverse_check_box->setToolTip(QCoreApplication::translate("qlearnframe", "If checked, use the inverse feature of the\n"
"control. Generally not needed, though.", nullptr));
#endif // QT_CONFIG(tooltip)
        inverse_check_box->setText(QCoreApplication::translate("qlearnframe", "&Inverse", nullptr));
        label_2->setText(QCoreApplication::translate("qlearnframe", "d1min", nullptr));
        d1min_line_edit->setText(QCoreApplication::translate("qlearnframe", "0", nullptr));
        label_3->setText(QCoreApplication::translate("qlearnframe", "d1max", nullptr));
        d1max_line_edit->setText(QCoreApplication::translate("qlearnframe", "127", nullptr));
#if QT_CONFIG(tooltip)
        ok_push_button->setToolTip(QCoreApplication::translate("qlearnframe", "Accepts the changes, making them official,\n"
"and flags for the saving of the 'ctrl' file\n"
"at exit.", nullptr));
#endif // QT_CONFIG(tooltip)
        ok_push_button->setText(QCoreApplication::translate("qlearnframe", "&OK", nullptr));
#if QT_CONFIG(tooltip)
        cancel_push_button->setToolTip(QCoreApplication::translate("qlearnframe", "Exit without any saving changes made since the\n"
"last Save.", nullptr));
#endif // QT_CONFIG(tooltip)
        cancel_push_button->setText(QCoreApplication::translate("qlearnframe", "Cancel", nullptr));
#if QT_CONFIG(tooltip)
        save_push_button->setToolTip(QCoreApplication::translate("qlearnframe", "Copies the current MIDI control set\n"
"to the original/reset control set.", nullptr));
#endif // QT_CONFIG(tooltip)
        save_push_button->setText(QCoreApplication::translate("qlearnframe", "Sa&ve", nullptr));
#if QT_CONFIG(tooltip)
        reset_push_button->setToolTip(QCoreApplication::translate("qlearnframe", "Copy the original or saved control set to\n"
"the current control set. An \"undo\" function.", nullptr));
#endif // QT_CONFIG(tooltip)
        reset_push_button->setText(QCoreApplication::translate("qlearnframe", "&Reset", nullptr));
        clear_push_button->setText(QCoreApplication::translate("qlearnframe", "Clear Automation", nullptr));
#if QT_CONFIG(tooltip)
        clear_all_push_button->setToolTip(QCoreApplication::translate("qlearnframe", "Erase all events and substitute them with\n"
"blank MIDI control values.", nullptr));
#endif // QT_CONFIG(tooltip)
        clear_all_push_button->setText(QCoreApplication::translate("qlearnframe", "&Clear All", nullptr));
    } // retranslateUi

};

namespace Ui {
    class qlearnframe: public Ui_qlearnframe {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QLEARNFRAME_H
