/****************************************************************************
** Meta object code from reading C++ file 'qsessionframe.hpp'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../seq66-0.99.27/seq_qt5/src/gui/qsessionframe.hpp"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qsessionframe.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_seq66__qsessionframe_t {
    QByteArrayData data[13];
    char stringdata0[200];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_seq66__qsessionframe_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_seq66__qsessionframe_t qt_meta_stringdata_seq66__qsessionframe = {
    {
QT_MOC_LITERAL(0, 0, 20), // "seq66::qsessionframe"
QT_MOC_LITERAL(1, 21, 16), // "slot_flag_reload"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 20), // "slot_songinfo_change"
QT_MOC_LITERAL(4, 60, 14), // "slot_save_info"
QT_MOC_LITERAL(5, 75, 17), // "slot_track_number"
QT_MOC_LITERAL(6, 93, 3), // "trk"
QT_MOC_LITERAL(7, 97, 18), // "slot_macros_active"
QT_MOC_LITERAL(8, 116, 15), // "slot_macro_pick"
QT_MOC_LITERAL(9, 132, 15), // "slot_macro_send"
QT_MOC_LITERAL(10, 148, 17), // "slot_macro_delete"
QT_MOC_LITERAL(11, 166, 13), // "slot_log_file"
QT_MOC_LITERAL(12, 180, 19) // "slot_log_file_clear"

    },
    "seq66::qsessionframe\0slot_flag_reload\0"
    "\0slot_songinfo_change\0slot_save_info\0"
    "slot_track_number\0trk\0slot_macros_active\0"
    "slot_macro_pick\0slot_macro_send\0"
    "slot_macro_delete\0slot_log_file\0"
    "slot_log_file_clear"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_seq66__qsessionframe[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x08 /* Private */,
       3,    0,   65,    2, 0x08 /* Private */,
       4,    0,   66,    2, 0x08 /* Private */,
       5,    1,   67,    2, 0x08 /* Private */,
       7,    0,   70,    2, 0x08 /* Private */,
       8,    1,   71,    2, 0x08 /* Private */,
       9,    0,   74,    2, 0x08 /* Private */,
      10,    0,   75,    2, 0x08 /* Private */,
      11,    0,   76,    2, 0x08 /* Private */,
      12,    0,   77,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void seq66::qsessionframe::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<qsessionframe *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slot_flag_reload(); break;
        case 1: _t->slot_songinfo_change(); break;
        case 2: _t->slot_save_info(); break;
        case 3: _t->slot_track_number((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->slot_macros_active(); break;
        case 5: _t->slot_macro_pick((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->slot_macro_send(); break;
        case 7: _t->slot_macro_delete(); break;
        case 8: _t->slot_log_file(); break;
        case 9: _t->slot_log_file_clear(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject seq66::qsessionframe::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_seq66__qsessionframe.data,
    qt_meta_data_seq66__qsessionframe,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *seq66::qsessionframe::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *seq66::qsessionframe::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_seq66__qsessionframe.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "performer::callbacks"))
        return static_cast< performer::callbacks*>(this);
    return QFrame::qt_metacast(_clname);
}

int seq66::qsessionframe::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
